spoon.routing.RoutingProtocolError

Package spoon :: Package routing :: Class RoutingProtocolError |
[show private | hide private]
[frames | no frames]

## Class RoutingProtocolError

    Exception --+
                |
               RoutingProtocolError

Known Subclasses:
  `NodeUnreachable`

Method Summary
Inherited from Exception
| ``__init__`(...)`
| ``__getitem__`(...)`
| ``__str__`(...)`

Generated by Epydoc 2.1 on Sun Nov 26 15:27:51 2006 | http://epydoc.sf.net